@@ -4,7 +4,7 @@ cartographic projections and coordinate transformations library.
 
 Download: http://python.org/pypi/pyproj
 
-Requirements: Python 3.5+.
+Requirements: Python 3.6+.
 
 Contact:  Jeffrey Whitaker <jeffrey.s.whitaker@noaa.gov>
 
@@ -28,7 +28,7 @@ HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTIO
 OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """
-__version__ = "2.6.1.post1"
+__version__ = "3.0.0.post1"
 __all__ = [
     "Proj",
     "Geod",
@@ -38,7 +38,6 @@ __all__ = [
     "itransform",
     "pj_ellps",
     "pj_list",
-    "get_angular_units_map",
     "get_ellps_map",
     "get_prime_meridians_map",
     "get_proj_operations_map",
@@ -47,27 +46,35 @@ __all__ = [
 ]
 import warnings
 
-from pyproj import _datadir
-from pyproj._list import (  # noqa: F401
-    get_angular_units_map,
-    get_authorities,
-    get_codes,
-    get_ellps_map,
-    get_prime_meridians_map,
-    get_proj_operations_map,
-    get_units_map,
+import pyproj.network
+from pyproj._datadir import (  # noqa: F401
+    _pyproj_global_context_initialize,
+    set_use_global_context,
 )
 from pyproj._show_versions import show_versions  # noqa: F401
 from pyproj.crs import CRS  # noqa: F401
+from pyproj.database import get_authorities, get_codes, get_units_map  # noqa: F401
 from pyproj.exceptions import DataDirError, ProjError  # noqa: F401
 from pyproj.geod import Geod, geodesic_version_str, pj_ellps  # noqa: F401
-from pyproj.proj import Proj, pj_list, proj_version_str  # noqa: F401
-from pyproj.transformer import Transformer, itransform, transform  # noqa: F401
+from pyproj.list import (  # noqa: F401
+    get_ellps_map,
+    get_prime_meridians_map,
+    get_proj_operations_map,
+)
+from pyproj.proj import Proj, pj_list  # noqa: F401
+from pyproj.transformer import (  # noqa: F401
+    Transformer,
+    itransform,
+    proj_version_str,
+    transform,
+)
 
 __proj_version__ = proj_version_str
 
 
 try:
-    _datadir.pyproj_global_context_initialize()
+    _pyproj_global_context_initialize()
 except DataDirError as err:
     warnings.warn(str(err))
+
+pyproj.network.set_ca_bundle_path()
